@@ -127,7 +127,7 @@ use constant IS_CGI      => IS_MOD_PERL || exists $ENV{'GATEWAY_INTERFACE'};
 # we use a Hash to store the configuration. This is simpler to pass to functions.
 our %config;
 
-$config{version}                  = "26.03.02";  # year.month.day
+$config{version}                  = "26.03.03";  # year.month.day
 
 my $dirname = abs_path(dirname(__FILE__));
 
@@ -968,7 +968,7 @@ if (not $error) {
     $cmd .= " --key=$config{certificate_key}";
   }
   
-  $cmd .= " $session{port}";
+  $cmd .= " $session{qemuvnc_ip}:$session{port}";
   if ($config{service_port_multiple}) {
     $cmd .= " $session{qemuvnc_ip}:$session{port_vnc}";
   }
